@@ -66,12 +66,9 @@ def process_mux_signals(signals):
     return mux_signals
 
 
-def write_dbc(j, dbc, logger):
+def write_dbc(spec, dbc, logger):
     logger.info("Writing dbc file")
 
-    spec = Spec()
-    spec.decompile(j)
-
     messages = []
     nodes = []
 
